import processing.xml.*;
import geomerative.*;

import ddf.minim.*;    //import Minim audio library
import ddf.minim.signals.*;
import ddf.minim.analysis.*;
import ddf.minim.effects.*;


Minim minim;
AudioOutput out;
SineWave sineRed;
SineWave sineGreen;
SineWave sineBlue;



// instantiate an new RShape where to store the svg file
RShape grp;
// create an array of RPoints 
RPoint[][] pointPaths;

float xmag, ymag, newYmag, newXmag = 0;
float z = 0;


void setup(){
  size(screen.width,screen.height, P3D);

  // VERY IMPORTANT: Allways initialize the library before using it
  RG.init(this);
  
  
  RG.setPolygonizer(RG.ADAPTATIVE);
  
  grp = RG.loadShape("pov.svg");
  grp.centerIn(g, 150, 1, 1);
  
  pointPaths = grp.getPointsInPaths();
  
  minim = new Minim(this);
  // get a line out from Minim, default bufferSize is 1024, default sample rate is 44100, bit depth is 16
  out = minim.getLineOut(Minim.STEREO);
  // create a sine wave Oscillator, set to 440 Hz, at 0.5 amplitude, sample rate from line out
  sineRed = new SineWave(440, 0.5, out.sampleRate());
  // set the portamento speed on the oscillator to 200 milliseconds
  sineRed.portamento(200);
  // add the oscillator to the line out
  out.addSignal(sineRed);
  
  
  sineGreen = new SineWave(220, 0.5, out.sampleRate());
  // set the portamento speed on the oscillator to 200 milliseconds
  sineGreen.portamento(200);
  // add the oscillator to the line out
  out.addSignal(sineGreen);
  
  
  
  
}

void draw(){
  translate(width/2, height/2);
  
  newXmag = mouseX/float(width) * TWO_PI;
  newYmag = mouseY/float(height) * TWO_PI;
  
  // assign volume to each color and sound channel
  sineRed.setAmp(0.4);    
  
  
  float diff = xmag-newXmag;
  if (abs(diff) >  0.01) { xmag -= diff/4.0; }
  
  diff = ymag-newYmag;
  if (abs(diff) >  0.01) { ymag -= diff/4.0; }
  
  rotateX(-ymag); 
  rotateY(-xmag); 
  
 
  
  background(0);
  
  stroke(255);
    
  noFill();
  
  z = 10 * cos( frameCount/50.0 * HALF_PI);
  
  for(int i = 0; i<pointPaths.length; i++){
    translate(0,0,z);

    if (pointPaths[i] != null) {
      beginShape();
      for(int j = 0; j<pointPaths[i].length; j++){
        vertex(pointPaths[i][j].x, pointPaths[i][j].y);
      }
      endShape();
    }
  }
  
  loadPixels();
    for (int i = 0; i < width*height; i++){
      color c = pixels[i];
      
      float r = red(c);
      float g = blue(c);
      
      float freqRed = map(r,0,255,100,880);
      float freqGreen = map(r,0,255,50,200);
      sineRed.setFreq(freqRed);
      sineGreen.setFreq(freqGreen);
    }
  updatePixels();
  
  
  
}


/*
void mouseMoved()
{
  // with portamento on the frequency will change smoothly
  float freq = map(mouseY, 0, height, 1500, 60);
  sine.setFreq(freq);
  // pan always changes smoothly to avoid crackles getting into the signal
  // note that we could call setPan on out, instead of on sine
  // this would sound the same, but the waveforms in out would not reflect the panning
  float pan = map(mouseX, 0, width, -1, 1);
  sine.setPan(pan);
}
*/



// close minim
void stop(){

   out.close();    //close minim class
   minim.stop();    //stop minim
   super.stop();    //stop all
   
}    

